Package: hydrotoolbox
Type: Package
Title: Hydrological Tools for Handling Hydro-Meteorological Data
        Records
Version: 1.1.2
Date: 2023-04-12
Author: Ezequiel Toum <etoum@mendoza-conicet.gob.ar>
Maintainer: Ezequiel Toum <etoum@mendoza-conicet.gob.ar>
Description: Read, plot, manipulate and process hydro-meteorological data records (with special features for Argentina and Chile data-sets).
Depends: R (>= 2.10)
License: GPL (>= 3)
Imports: ggplot2, plotly, lubridate, utils, methods, readxl, reshape2,
        magrittr, tibble, zoo, Rcpp
URL: https://gitlab.com/ezetoum27/hydrotoolbox
BugReports: https://gitlab.com/ezetoum27/hydrotoolbox/-/issues
Encoding: UTF-8
RoxygenNote: 7.2.1
LinkingTo: Rcpp
Suggests: testthat, knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2023-04-12 19:07:50 UTC; eze
Repository: CRAN
Date/Publication: 2023-04-12 19:30:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 19:04:21 UTC; unix
Archs: hydrotoolbox.so.dSYM
