# Generated by roxygen2: do not edit by hand

export("%>%")
export(agg2annually)
export(agg2climatic)
export(agg2daily)
export(agg2hourly)
export(agg2monthly)
export(agg_table)
export(build_table)
export(col_stats)
export(cum_sum)
export(dual_y_table)
export(fill_table)
export(ggplot_table)
export(hm_agg)
export(hm_build)
export(hm_build_generic)
export(hm_create)
export(hm_get)
export(hm_melt)
export(hm_mutate)
export(hm_name)
export(hm_plot)
export(hm_report)
export(hm_set)
export(hm_show)
export(hm_subset)
export(hydromet)
export(hydromet_compact)
export(hydromet_station)
export(interpolate)
export(mov_avg)
export(qm_vol)
export(read_aic)
export(read_cr2)
export(read_dgi)
export(read_ianigla)
export(read_mnemos)
export(read_snih)
export(report_miss)
export(rm_spike)
export(roll_fun)
export(set_threshold)
export(set_value)
export(swe_derive)
exportClasses(hydromet)
exportClasses(hydromet_compact)
exportClasses(hydromet_station)
import(ggplot2)
importFrom(Rcpp,sourceCpp)
importFrom(grDevices,colors)
importFrom(grDevices,heat.colors)
importFrom(lubridate,"month<-")
importFrom(lubridate,month)
importFrom(magrittr,"%>%")
importFrom(methods,callNextMethod)
importFrom(methods,getSlots)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,slotNames)
importFrom(methods,validObject)
importFrom(plotly,"%>%")
importFrom(plotly,add_trace)
importFrom(plotly,ggplotly)
importFrom(plotly,layout)
importFrom(plotly,plot_ly)
importFrom(readxl,excel_sheets)
importFrom(readxl,read_xls)
importFrom(readxl,read_xlsx)
importFrom(reshape2,melt)
importFrom(stats,approx)
importFrom(stats,na.omit)
importFrom(tibble,as_tibble)
importFrom(utils,head)
importFrom(utils,read.csv)
importFrom(utils,tail)
importFrom(zoo,rollapplyr)
useDynLib(hydrotoolbox, .registration = TRUE)
