hydrotoolbox indices --start_date 1990-10-01 --end_date 2000-09-30 MA1,MA2,MA3,MA4,MA5,MA6,MA7,MA8,MA9,MA10,MA11,MA12,MA13,MA14,MA15,MA16,MA17,MA18,MA19,MA20,MA21,MA22,MA23,MA24,MA25,MA26,MA27,MA28,MA29,MA30,MA31,MA32,MA33,MA34,MA35,MA36,MA37,MA38,MA39,MA40,MA41,MA42,MA43,MA44,MA45,ML1,ML2,ML3,ML4,ML5,ML6,ML7,ML8,ML9,ML10,ML11,ML12,ML13,ML14,ML15,ML16,ML17,ML18,ML19,ML20,ML21,ML22,MH1,MH2,MH3,MH4,MH5,MH6,MH7,MH8,MH9,MH10,MH11,MH12,MH13,MH14,MH15,MH16,MH17,MH18,MH19,MH20,MH21,MH22,MH23,MH24,MH25,MH26,MH27,FL1,FL2,FL3,FH1,FH2,FH3,FH4,FH5,FH6,FH7,FH8,FH9,FH10,DL1,DL2,DL3,DL4,DL5,DL6,DL7,DL8,DL9,DL10,DL11,DL12,DL13,DL14,DL15,DL16,DL17,DL18,DL19,DL20,DH1,DH2,DH3,DH4,DH5,DH6,DH7,DH8,DH9,DH10,DH11,DH12,DH13,DH14,DH15,DH16,DH17,DH18,DH19,DH20,DH21,TA1,TA2,TL1,TL2,TH1,TH2,RA1,RA2,RA3,RA4,RA5,RA6,RA7,RA8,RA9 < Q_BEC_BE_6500.csv > hydrotoolbox_indices.txt
tsproc tsproc_hydrologic_indices.inp tsproc_hydrologic_indices.rec context_1 > /dev/null
tail -n +3 gtable.out > tmp.txt
paste tmp.txt hydrotoolbox_indices.txt
